==> billogram-foundation-3.11.0.tgz: package/modules/components/dropdown/DropdownContainer.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import actionName from '../../utils/actionName';
import getComponentState from '../../utils/getComponentState';

import dropdownCollapse from './redux/dropdownCollapse';
import dropdownChange from './redux/dropdownChange';
import dropdownExpand from './redux/dropdownExpand';
import dropdownHighlightedIndexChange from './redux/dropdownHighlightedIndexChange';


const changeType = actionName('CHANGE');
const collapseType = actionName('COLLAPSE');
const expandType = actionName('EXPAND');
const highlightedIndexChangeType = actionName('HIGHLIGHTED-INDEX-CHANGE');

export {
    changeType,
    collapseType,
    expandType,
    highlightedIndexChangeType
};

export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Dropdown component.');

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        mixins: [PureRenderMixin],

        propTypes: {
            actionTypePrefix: PropTypes.string,
            customActionMetadata: PropTypes.object,
            path: PropTypes.string,
            root: PropTypes.string
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapStateToProps = (state, props) => {
        const { expanded, highlightedIndex, options, value } = getComponentState(state, props);
        return {
            expanded,
            highlightedIndex,
            options,
            value
        };
    };

    const mapDispatchToProps = (dispatch, props) => {
        const { customActionMetadata: custom, path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'DROPDOWN';

        return {
            onChange: (value) => dispatch(dropdownChange({ custom, path, root, type: changeType(actionTypePrefix), value })),
            onCollapse: () => dispatch(dropdownCollapse({ path, root, type: collapseType(actionTypePrefix) })),
            onExpand: () => dispatch(dropdownExpand({ path, root, type: expandType(actionTypePrefix) })),
            onHighlightedIndexChange: (highlightedIndex) => dispatch(dropdownHighlightedIndexChange({ highlightedIndex, path, root, type: highlightedIndexChangeType(actionTypePrefix) }))
        };
    };

    return connect(mapStateToProps, mapDispatchToProps)(Container);

};

==> billogram-foundation-3.13.10.tgz: package/modules/components/dropdown/DropdownContainer.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import actionName from '../../utils/actionName';
import getComponentState from '../../utils/getComponentState';

import dropdownCollapse from './redux/dropdownCollapse';
import dropdownChange from './redux/dropdownChange';
import dropdownExpand from './redux/dropdownExpand';
import dropdownHighlightedIndexChange from './redux/dropdownHighlightedIndexChange';


export const changeType = actionName('CHANGE');
export const collapseType = actionName('COLLAPSE');
export const expandType = actionName('EXPAND');
export const highlightedIndexChangeType = actionName('HIGHLIGHTED-INDEX-CHANGE');

export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Dropdown component.');

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        mixins: [PureRenderMixin],

        propTypes: {
            actionTypePrefix: PropTypes.string,
            customActionMetadata: PropTypes.object,
            path: PropTypes.string,
            root: PropTypes.string
        },

        render() {
            return (
                <Component { ...this.props } />
            );
        }

    });

    const mapDispatchToProps = (dispatch, props) => {
        const { customActionMetadata: custom, path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'DROPDOWN';

        return {
            onChange: (value) => dispatch(dropdownChange({ custom, path, root, type: changeType(actionTypePrefix), value })),
            onCollapse: () => dispatch(dropdownCollapse({ path, root, type: collapseType(actionTypePrefix) })),
            onExpand: () => dispatch(dropdownExpand({ path, root, type: expandType(actionTypePrefix) })),
            onHighlightedIndexChange: (highlightedIndex) => dispatch(dropdownHighlightedIndexChange({ highlightedIndex, path, root, type: highlightedIndexChangeType(actionTypePrefix) }))
        };
    };

    return connect(getComponentState, mapDispatchToProps)(Container);

};
